@@ -1,9 +1,9 @@
 package HTTP::Throwable::Role::Status::MethodNotAllowed;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::MethodNotAllowed::VERSION = '0.026';
+$HTTP::Throwable::Role::Status::MethodNotAllowed::VERSION = '0.027';
 use Type::Utils qw(subtype as where enum);
 use Types::Standard qw(ArrayRef);
-use List::AllUtils qw[ uniq ];
+use List::Util 1.45 qw[ uniq ];
 
 use Moo::Role;
 
@@ -54,7 +54,7 @@ HTTP::Throwable::Role::Status::MethodNotAllowed - 405 Method Not Allowed
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 DESCRIPTION
 
@@ -90,7 +90,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc..
+This software is copyright (c) 2011 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
